@@ -1,5 +1,6 @@
 var NAVTREEINDEX15 =
 {
+"classzypp_1_1Digest.html#aba6b0715bbc1d9e26526fe28f13dd0f5":[4,0,7,92,21],
 "classzypp_1_1Digest.html#ac92ffcdc657105bb332bc958819122f0":[3,0,10,101,14],
 "classzypp_1_1Digest.html#ac92ffcdc657105bb332bc958819122f0":[4,0,7,92,14],
 "classzypp_1_1Digest.html#adea57aeee5846b70c84749565e010e3c":[3,0,10,101,24],
@@ -74,7 +75,7 @@ var NAVTREEINDEX15 =
 "classzypp_1_1DiskUsageCounter.html#ab2d5f8d6604100ae36b94c6ac4723c63":[4,0,7,94,11],
 "classzypp_1_1DiskUsageCounter.html#ad20cdb7dfed2b63a82f81eb1a5dea0e0":[3,0,10,103,3],
 "classzypp_1_1DiskUsageCounter.html#ad20cdb7dfed2b63a82f81eb1a5dea0e0":[4,0,7,94,3],
-"classzypp_1_1DiskUsageCounter.html#af6a83d2091294cdd76d1696a96357432":[3,0,10,678],
+"classzypp_1_1DiskUsageCounter.html#af6a83d2091294cdd76d1696a96357432":[3,0,10,686],
 "classzypp_1_1DiskUsageCounter.html#af6a83d2091294cdd76d1696a96357432":[3,0,10,103,15],
 "classzypp_1_1DiskUsageCounter.html#af6a83d2091294cdd76d1696a96357432":[4,0,7,94,15],
 "classzypp_1_1DtorReset.html":[3,0,10,104],
@@ -107,7 +108,7 @@ var NAVTREEINDEX15 =
 "classzypp_1_1Edition.html#a3780bfb416066b1774d438b595bd0c84":[4,0,7,96,2],
 "classzypp_1_1Edition.html#a38aba6bb63650853aeb945d803e04782":[3,0,10,105,29],
 "classzypp_1_1Edition.html#a38aba6bb63650853aeb945d803e04782":[4,0,7,96,29],
-"classzypp_1_1Edition.html#a3fee699ef6571a292d1f6ecbd7f97a04":[3,0,10,679],
+"classzypp_1_1Edition.html#a3fee699ef6571a292d1f6ecbd7f97a04":[3,0,10,687],
 "classzypp_1_1Edition.html#a3fee699ef6571a292d1f6ecbd7f97a04":[3,0,10,105,40],
 "classzypp_1_1Edition.html#a3fee699ef6571a292d1f6ecbd7f97a04":[4,0,7,96,40],
 "classzypp_1_1Edition.html#a414d895d0767ab9e9c0ccdd0f9e85333":[3,0,10,105,41],
@@ -188,7 +189,7 @@ var NAVTREEINDEX15 =
 "classzypp_1_1Errno.html#a5a74d4d054056361eb6ac93d52e2af21":[4,0,7,98,5],
 "classzypp_1_1Errno.html#a6572d6ac51743cd10d7216a7fd576c1c":[3,0,10,107,1],
 "classzypp_1_1Errno.html#a6572d6ac51743cd10d7216a7fd576c1c":[4,0,7,98,1],
-"classzypp_1_1Errno.html#a8ab6b470bdd87a9454a016218dd87cb6":[3,0,10,763],
+"classzypp_1_1Errno.html#a8ab6b470bdd87a9454a016218dd87cb6":[3,0,10,771],
 "classzypp_1_1Errno.html#a8ab6b470bdd87a9454a016218dd87cb6":[3,0,10,107,6],
 "classzypp_1_1Errno.html#a8ab6b470bdd87a9454a016218dd87cb6":[4,0,7,98,6],
 "classzypp_1_1Errno.html#aa7f7c13f8729a56374609c1ea6be6c68":[3,0,10,107,7],
@@ -248,6 +249,5 @@ var NAVTREEINDEX15 =
 "classzypp_1_1Exception.html#a96dc80247b8ff510b006a29b1d215824":[3,0,10,110,37],
 "classzypp_1_1Exception.html#a96dc80247b8ff510b006a29b1d215824":[4,0,7,101,37],
 "classzypp_1_1Exception.html#a9b6b4359936c74f0a4ecc0cf2d5c0c99":[3,0,10,110,4],
-"classzypp_1_1Exception.html#a9b6b4359936c74f0a4ecc0cf2d5c0c99":[4,0,7,101,4],
-"classzypp_1_1Exception.html#aa2e831e022ace14a60cd613bc5e93038":[3,0,10,110,7]
+"classzypp_1_1Exception.html#a9b6b4359936c74f0a4ecc0cf2d5c0c99":[4,0,7,101,4]
 };
