@@ -1,5 +1,6 @@
 var NAVTREEINDEX16 =
 {
+"classzypp_1_1Exception.html#aa2e831e022ace14a60cd613bc5e93038":[3,0,10,110,7],
 "classzypp_1_1Exception.html#aa2e831e022ace14a60cd613bc5e93038":[4,0,7,101,7],
 "classzypp_1_1Exception.html#aa414c262b7bd5c910a0000ccbfe08d04":[3,0,10,110,15],
 "classzypp_1_1Exception.html#aa414c262b7bd5c910a0000ccbfe08d04":[4,0,7,101,15],
@@ -25,7 +26,7 @@ var NAVTREEINDEX16 =
 "classzypp_1_1Exception.html#adbed782d4b284c7bdb4554c2f2aca324":[4,0,7,101,13],
 "classzypp_1_1Exception.html#adfa4b6972bcdc173455d7a01068e221a":[3,0,10,110,30],
 "classzypp_1_1Exception.html#adfa4b6972bcdc173455d7a01068e221a":[4,0,7,101,30],
-"classzypp_1_1Exception.html#ae2959336c7bf3ad65daa82a1b3f5db0d":[3,0,10,764],
+"classzypp_1_1Exception.html#ae2959336c7bf3ad65daa82a1b3f5db0d":[3,0,10,772],
 "classzypp_1_1Exception.html#ae2959336c7bf3ad65daa82a1b3f5db0d":[3,0,10,110,41],
 "classzypp_1_1Exception.html#ae2959336c7bf3ad65daa82a1b3f5db0d":[4,0,7,101,41],
 "classzypp_1_1Exception.html#ae4e984428c1a3b9681ee7c2080731337":[3,0,10,110,12],
@@ -134,7 +135,7 @@ var NAVTREEINDEX16 =
 "classzypp_1_1Fetcher.html#a28b775d82981d5bd19bb91b18f502bae":[4,0,7,105,8],
 "classzypp_1_1Fetcher.html#a2a47459ad8aeb3228a88d8c2e1959e10":[3,0,10,114,7],
 "classzypp_1_1Fetcher.html#a2a47459ad8aeb3228a88d8c2e1959e10":[4,0,7,105,7],
-"classzypp_1_1Fetcher.html#a2b6e2ecbf365b3808310e612e470b335":[3,0,10,680],
+"classzypp_1_1Fetcher.html#a2b6e2ecbf365b3808310e612e470b335":[3,0,10,688],
 "classzypp_1_1Fetcher.html#a2b6e2ecbf365b3808310e612e470b335":[3,0,10,114,20],
 "classzypp_1_1Fetcher.html#a2b6e2ecbf365b3808310e612e470b335":[3,0,10,114,22],
 "classzypp_1_1Fetcher.html#a2b6e2ecbf365b3808310e612e470b335":[4,0,7,105,20],
@@ -248,6 +249,5 @@ var NAVTREEINDEX16 =
 "classzypp_1_1Fetcher_1_1Impl.html#ac4a7c65497bb9085f34412f3ae8c83b0":[3,0,10,114,0,19],
 "classzypp_1_1Fetcher_1_1Impl.html#ac4a7c65497bb9085f34412f3ae8c83b0":[4,0,7,105,0,19],
 "classzypp_1_1Fetcher_1_1Impl.html#ad5c0fb5cb1ff99231007f8d2e159b468":[3,0,10,114,0,14],
-"classzypp_1_1Fetcher_1_1Impl.html#ad5c0fb5cb1ff99231007f8d2e159b468":[4,0,7,105,0,14],
-"classzypp_1_1Fetcher_1_1Impl.html#ad6f7c2785383eba1b3c3629c15779968":[3,0,10,114,0,17]
+"classzypp_1_1Fetcher_1_1Impl.html#ad5c0fb5cb1ff99231007f8d2e159b468":[4,0,7,105,0,14]
 };
