@@ -1,5 +1,6 @@
 var NAVTREEINDEX17 =
 {
+"classzypp_1_1Fetcher_1_1Impl.html#ad6f7c2785383eba1b3c3629c15779968":[3,0,10,114,0,17],
 "classzypp_1_1Fetcher_1_1Impl.html#ad6f7c2785383eba1b3c3629c15779968":[4,0,7,105,0,17],
 "classzypp_1_1Fetcher_1_1Impl.html#ae15ba079e7f7067c9dabfa93fc8b7737":[3,0,10,114,0,7],
 "classzypp_1_1Fetcher_1_1Impl.html#ae15ba079e7f7067c9dabfa93fc8b7737":[4,0,7,105,0,7],
@@ -79,7 +80,7 @@ var NAVTREEINDEX17 =
 "classzypp_1_1HistoryLogData.html#a974746bd8f65bc96a4e19f03723b2ff7ad9013da6e61a1470f022413450ec198d":[4,0,7,114,6,1],
 "classzypp_1_1HistoryLogData.html#a974746bd8f65bc96a4e19f03723b2ff7af49e86193318efbd886fda31d8b72db7":[3,0,10,123,6,0],
 "classzypp_1_1HistoryLogData.html#a974746bd8f65bc96a4e19f03723b2ff7af49e86193318efbd886fda31d8b72db7":[4,0,7,114,6,0],
-"classzypp_1_1HistoryLogData.html#a99d24820fc7df1d4204c8b386ed1d604":[3,0,10,684],
+"classzypp_1_1HistoryLogData.html#a99d24820fc7df1d4204c8b386ed1d604":[3,0,10,692],
 "classzypp_1_1HistoryLogData.html#a99d24820fc7df1d4204c8b386ed1d604":[3,0,10,123,21],
 "classzypp_1_1HistoryLogData.html#a99d24820fc7df1d4204c8b386ed1d604":[4,0,7,114,21],
 "classzypp_1_1HistoryLogData.html#ab0de4e4b466d9b7bd554c4794dbf0da4":[3,0,10,123,16],
@@ -248,6 +249,5 @@ var NAVTREEINDEX17 =
 "classzypp_1_1HistoryLogDataRepoRemove.html#a894bd8b4a592214460276c90c7c13a28":[4,0,7,119,5],
 "classzypp_1_1HistoryLogDataRepoRemove.html#abf251c8ca6ff3594b7b1523d528c3f14":[3,0,10,128,0],
 "classzypp_1_1HistoryLogDataRepoRemove.html#abf251c8ca6ff3594b7b1523d528c3f14":[4,0,7,119,0],
-"classzypp_1_1HistoryLogDataRepoUrlChange.html":[3,0,10,129],
-"classzypp_1_1HistoryLogDataRepoUrlChange.html":[4,0,7,120]
+"classzypp_1_1HistoryLogDataRepoUrlChange.html":[3,0,10,129]
 };
